---
title: 해외결제 지원 결제대행사 목록
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 해외결제
seo:
  title: 결제대행사별 특징 | 해외결제
  description: 해외결제를 지원하는 결제대행사 목록입니다. 결제대행사별 해외결제 서비스를 비교,검토하시어 이용하실 결제대행사를 결정하시기 바랍니다.
tags:
  - 공통
  - 해외결제
pgCompanies:
  - 엑심베이
  - 페이먼트월
  - 페이팔
  - 토스페이먼츠
  - 나이스페이먼츠
  - KG이니시스
  - NHN KCP
searchTags:
  - 해외카드
  - 해외결제지원
  - 해외결제 pg사
  - 헤외결제 지원 pg사
  - 해외결제 지원
datetime: 2024-03-18T06:45:29.257Z
---

<Callout content="해외결제를 지원하는 결제대행사 목록과 그 특징을 안내드립니다." />

### **해외결제 지원 결제대행사 목록**

1. **해외카드 + 현지결제 지원 결제대행사 : 페이먼트월, 페이팔, 엑심베이**

- [페이먼트월 해외결제 서비스 이용안내 보러가기↗](/content/paymentwall-international)
- [페이팔 해외결제 서비스 이용안내 보러가기↗](/content/paypal-international)
- [엑심베이 해외결제 서비스 이용안내 보러가기↗](/content/eximbay-international)

**2. 해외카드 지원 국내 결제대행사 :  KG이니시스, NHN KCP, 나이스페이먼츠, 토스페이먼츠**

- 국내PG사를 통해서 해외특약을 맺고, 해외결제를 이용하실 수 있습니다.
- 단, 사업자는 반드시 국내사업자(해외사업자 불가)여야 하는 점 참고해주세요!
- 정기결제는 지원 되지 않습니다.

